@@ -1,5 +1,5 @@
 /* ANSI-C code produced by gperf version 3.1 */
-/* Command-line: gperf -m 10 ../../lib/unictype/bidi_byname.gperf  */
+/* Command-line: gperf -m 10 ./unictype/bidi_byname.gperf  */
 /* Computed positions: -k'1,9,$' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -29,7 +29,7 @@
 #error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
-#line 2 "../../lib/unictype/bidi_byname.gperf"
+#line 2 "./unictype/bidi_byname.gperf"
 struct named_bidi_class { int name; int bidi_class; };
 
 #define TOTAL_KEYWORDS 69
@@ -289,153 +289,153 @@ static const struct bidi_class_stringpool_t bidi_class_stringpool_contents =
 static const struct named_bidi_class bidi_class_names[] =
   {
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 31 "../../lib/unictype/bidi_byname.gperf"
+#line 31 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str5, UC_BIDI_R},
-#line 19 "../../lib/unictype/bidi_byname.gperf"
+#line 19 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str6, UC_BIDI_EN},
-#line 32 "../../lib/unictype/bidi_byname.gperf"
+#line 32 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str7, UC_BIDI_RLE},
     {-1},
-#line 15 "../../lib/unictype/bidi_byname.gperf"
+#line 15 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str9, UC_BIDI_AN},
-#line 24 "../../lib/unictype/bidi_byname.gperf"
+#line 24 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str10, UC_BIDI_LRE},
-#line 23 "../../lib/unictype/bidi_byname.gperf"
+#line 23 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str11, UC_BIDI_L},
-#line 14 "../../lib/unictype/bidi_byname.gperf"
+#line 14 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str12, UC_BIDI_AL},
-#line 28 "../../lib/unictype/bidi_byname.gperf"
+#line 28 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str13, UC_BIDI_ON},
-#line 34 "../../lib/unictype/bidi_byname.gperf"
+#line 34 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str14, UC_BIDI_RLO},
     {-1},
-#line 33 "../../lib/unictype/bidi_byname.gperf"
+#line 33 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str16, UC_BIDI_RLI},
-#line 26 "../../lib/unictype/bidi_byname.gperf"
+#line 26 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str17, UC_BIDI_LRO},
-#line 30 "../../lib/unictype/bidi_byname.gperf"
+#line 30 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str18, UC_BIDI_PDI},
-#line 25 "../../lib/unictype/bidi_byname.gperf"
+#line 25 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str19, UC_BIDI_LRI},
-#line 48 "../../lib/unictype/bidi_byname.gperf"
+#line 48 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str20, UC_BIDI_EN},
     {-1},
-#line 37 "../../lib/unictype/bidi_byname.gperf"
+#line 37 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str22, UC_BIDI_AL},
     {-1},
-#line 76 "../../lib/unictype/bidi_byname.gperf"
+#line 76 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str24, UC_BIDI_RLI},
-#line 78 "../../lib/unictype/bidi_byname.gperf"
+#line 78 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str25, UC_BIDI_RLO},
-#line 74 "../../lib/unictype/bidi_byname.gperf"
+#line 74 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str26, UC_BIDI_RLE},
-#line 60 "../../lib/unictype/bidi_byname.gperf"
+#line 60 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str27, UC_BIDI_LRI},
-#line 62 "../../lib/unictype/bidi_byname.gperf"
+#line 62 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str28, UC_BIDI_LRO},
-#line 58 "../../lib/unictype/bidi_byname.gperf"
+#line 58 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str29, UC_BIDI_LRE},
-#line 59 "../../lib/unictype/bidi_byname.gperf"
+#line 59 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str30, UC_BIDI_LRI},
-#line 61 "../../lib/unictype/bidi_byname.gperf"
+#line 61 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str31, UC_BIDI_LRO},
-#line 57 "../../lib/unictype/bidi_byname.gperf"
+#line 57 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str32, UC_BIDI_LRE},
-#line 47 "../../lib/unictype/bidi_byname.gperf"
+#line 47 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str33, UC_BIDI_EN},
-#line 21 "../../lib/unictype/bidi_byname.gperf"
+#line 21 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str34, UC_BIDI_ET},
-#line 17 "../../lib/unictype/bidi_byname.gperf"
+#line 17 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str35, UC_BIDI_BN},
-#line 49 "../../lib/unictype/bidi_byname.gperf"
+#line 49 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str36, UC_BIDI_ES},
-#line 51 "../../lib/unictype/bidi_byname.gperf"
+#line 51 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str37, UC_BIDI_ET},
-#line 20 "../../lib/unictype/bidi_byname.gperf"
+#line 20 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str38, UC_BIDI_ES},
-#line 75 "../../lib/unictype/bidi_byname.gperf"
+#line 75 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str39, UC_BIDI_RLI},
-#line 77 "../../lib/unictype/bidi_byname.gperf"
+#line 77 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str40, UC_BIDI_RLO},
-#line 73 "../../lib/unictype/bidi_byname.gperf"
+#line 73 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str41, UC_BIDI_RLE},
-#line 45 "../../lib/unictype/bidi_byname.gperf"
+#line 45 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str42, UC_BIDI_CS},
-#line 46 "../../lib/unictype/bidi_byname.gperf"
+#line 46 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str43, UC_BIDI_CS},
     {-1},
-#line 72 "../../lib/unictype/bidi_byname.gperf"
+#line 72 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str45, UC_BIDI_R},
-#line 81 "../../lib/unictype/bidi_byname.gperf"
+#line 81 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str46, UC_BIDI_WS},
     {-1},
-#line 56 "../../lib/unictype/bidi_byname.gperf"
+#line 56 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str48, UC_BIDI_L},
-#line 38 "../../lib/unictype/bidi_byname.gperf"
+#line 38 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str49, UC_BIDI_AL},
-#line 55 "../../lib/unictype/bidi_byname.gperf"
+#line 55 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str50, UC_BIDI_L},
-#line 69 "../../lib/unictype/bidi_byname.gperf"
+#line 69 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str51, UC_BIDI_PDI},
-#line 52 "../../lib/unictype/bidi_byname.gperf"
+#line 52 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str52, UC_BIDI_ET},
-#line 44 "../../lib/unictype/bidi_byname.gperf"
+#line 44 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str53, UC_BIDI_BN},
-#line 80 "../../lib/unictype/bidi_byname.gperf"
+#line 80 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str54, UC_BIDI_S},
-#line 50 "../../lib/unictype/bidi_byname.gperf"
+#line 50 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str55, UC_BIDI_ES},
-#line 66 "../../lib/unictype/bidi_byname.gperf"
+#line 66 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str56, UC_BIDI_ON},
-#line 70 "../../lib/unictype/bidi_byname.gperf"
+#line 70 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str57, UC_BIDI_PDI},
-#line 18 "../../lib/unictype/bidi_byname.gperf"
+#line 18 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str58, UC_BIDI_CS},
-#line 71 "../../lib/unictype/bidi_byname.gperf"
+#line 71 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str59, UC_BIDI_R},
-#line 29 "../../lib/unictype/bidi_byname.gperf"
+#line 29 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str60, UC_BIDI_PDF},
-#line 39 "../../lib/unictype/bidi_byname.gperf"
+#line 39 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str61, UC_BIDI_AN},
-#line 82 "../../lib/unictype/bidi_byname.gperf"
+#line 82 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str62, UC_BIDI_WS},
-#line 16 "../../lib/unictype/bidi_byname.gperf"
+#line 16 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str63, UC_BIDI_B},
-#line 36 "../../lib/unictype/bidi_byname.gperf"
+#line 36 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str64, UC_BIDI_WS},
-#line 27 "../../lib/unictype/bidi_byname.gperf"
+#line 27 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str65, UC_BIDI_NSM},
-#line 43 "../../lib/unictype/bidi_byname.gperf"
+#line 43 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str66, UC_BIDI_BN},
-#line 22 "../../lib/unictype/bidi_byname.gperf"
+#line 22 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str67, UC_BIDI_FSI},
-#line 65 "../../lib/unictype/bidi_byname.gperf"
+#line 65 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str68, UC_BIDI_ON},
-#line 35 "../../lib/unictype/bidi_byname.gperf"
+#line 35 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str69, UC_BIDI_S},
-#line 64 "../../lib/unictype/bidi_byname.gperf"
+#line 64 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str70, UC_BIDI_NSM},
-#line 63 "../../lib/unictype/bidi_byname.gperf"
+#line 63 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str71, UC_BIDI_NSM},
-#line 42 "../../lib/unictype/bidi_byname.gperf"
+#line 42 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str72, UC_BIDI_B},
-#line 41 "../../lib/unictype/bidi_byname.gperf"
+#line 41 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str73, UC_BIDI_B},
     {-1}, {-1}, {-1},
-#line 53 "../../lib/unictype/bidi_byname.gperf"
+#line 53 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str77, UC_BIDI_FSI},
-#line 67 "../../lib/unictype/bidi_byname.gperf"
+#line 67 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str78, UC_BIDI_PDF},
-#line 40 "../../lib/unictype/bidi_byname.gperf"
+#line 40 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str79, UC_BIDI_AN},
     {-1}, {-1},
-#line 54 "../../lib/unictype/bidi_byname.gperf"
+#line 54 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str82, UC_BIDI_FSI},
     {-1},
-#line 68 "../../lib/unictype/bidi_byname.gperf"
+#line 68 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str84, UC_BIDI_PDF},
     {-1}, {-1},
-#line 79 "../../lib/unictype/bidi_byname.gperf"
+#line 79 "./unictype/bidi_byname.gperf"
     {(int)(size_t)&((struct bidi_class_stringpool_t *)0)->bidi_class_stringpool_str87, UC_BIDI_S}
   };
 
